from .__pytransform import pyarmor_runtime

"""
# MixtureMapping

[![Documentation](https://github.com/VK/dash-express-components/workflows/Publish%20release/badge.svg)](https://vk.github.io/mixturemapping-doc)
[![PyPI version](https://badge.fury.io/py/mixturemapping.svg)](https://badge.fury.io/py/mixturemapping)

Train Gaussian Mixture Mappings


## Provides:
  1. Layers to build tensorflow models to map Gaussian mixtures
  2. Tools to compute yield values of Gaussian mixtures in complex binning schemes

## Example
  
    import mixturemapping as mm  
    import tensorflow as tf

    inMeans = tf.keras.Input(shape=(mixN, inputMixM), name="Means", dtype=dataType)
    inStdDevs = tf.keras.Input(shape=(mixN, inputMixM), name="StdDevs", dtype=dataType)
    inWeight = tf.keras.Input(shape=(mixN), name="Weights", dtype=dataType)

    mapModel = tf.keras.Sequential()
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(outputMixM))
    y = mapModel(inMeans)

    deltaModel = tf.keras.Sequential()
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(outputMixM))
    yDelta = deltaModel(inMeans)

    covALayer = mm.layers.TrainableCovMatrix(outputMixM, name="CovA")
    covA = covALayer(inMeans)

    mapLayer = mm.layers.GeneralMapping(outputMixM, name="Mapping", dtype=dataType)
    newDist = mapLayer({'means': inMeans, 'y':y, 'yDelta':yDelta, 'stdDevs': inStdDevs, 'weights': inWeight, 'covA': covA})

    distLayer = mm.layers.Distribution(dtype=dataType, regularize_cov_epsilon=0.95)
    dist = distLayer(newDist)

### Developement
```
$ py -m venv env
$ .\env\Scripts\activate
$ pip install -r requirements.txt
```


"""


pyarmor_runtime()
__pyarmor__(__name__, __file__, b'\x50\x59\x41\x52\x4d\x4f\x52\x00\x00\x03\x07\x00\x42\x0d\x0d\x0a\x08\x2d\xa0\x01\x00\x00\x00\x00\x01\x00\x00\x00\x40\x00\x00\x00\x87\x08\x00\x00\x00\x00\x00\x18\x15\xbe\x0e\xd6\x89\x61\x6f\xa5\x5d\xb9\x4a\xdf\x56\x59\x5c\x60\x00\x00\x00\x00\x00\x00\x00\x00\x9c\xaf\x97\x68\x05\x2a\xd4\x02\x5f\x08\xba\x15\x08\xe6\x57\x20\x2f\xeb\x5b\xe9\xe4\x16\x5b\xcf\x3b\x61\x98\x1f\xf4\x63\x19\xe4\xea\x66\x71\xc9\x04\x5c\x9e\x34\xa8\x69\xf3\x0e\x06\x3c\x1a\x9b\xa9\x36\x1c\x98\x82\x10\xb3\x32\xc7\x6d\xc4\x07\xd6\x06\x70\x48\x4d\x62\x96\x2c\x3a\xff\x70\xc2\x02\xcd\x7f\x99\x9c\x88\x60\x8d\x6a\xd5\x05\xa4\xdd\xa7\xd0\xc9\x1c\xb3\x97\x5c\x08\x27\xbf\x9b\x0f\x5b\x1b\xf9\xdd\x1e\xae\xc9\x45\x5f\x13\x60\xdf\x0a\xa3\x71\xda\xdb\xb2\x8a\x71\x80\x8a\x11\x7a\x4f\x81\x2d\x55\x14\x77\xf6\x37\x3a\x27\xab\x85\x7b\x07\x25\x3a\x49\x4f\x49\xfa\xf7\x8f\x69\x13\x7b\x77\x2c\xaa\x11\x36\xcc\x7a\x3a\x46\xf3\x93\x3d\x77\x5a\xc5\x94\xae\x96\xa0\x4f\xb4\xba\x0d\xed\x3a\xec\x43\x1b\x35\xe4\x2a\x77\xfb\x45\xb0\xd1\x42\xb7\x6a\xf6\x8e\xc6\xfe\x6e\x37\x1a\x9d\xc3\x4e\x79\xdd\x64\x86\x83\xdf\x9e\xb7\xe8\x22\xe2\xc8\x5b\xb2\xa8\xf3\x3b\xb2\xd3\x92\x17\x5d\x5e\x6e\x86\x33\xdb\xf7\xd7\xc2\xd7\x3c\xf0\xa7\xff\x22\x7d\xaf\xb8\xe9\x0f\xca\x18\x43\x12\xf9\x2b\x91\x04\x77\x4e\x1d\xe0\x8e\xdc\xe5\x82\x0b\xe2\x3d\x73\x60\x03\x07\x6b\x8c\xe0\xfe\xef\x25\x4b\x5d\xfd\x91\x44\x60\xb6\x5c\xd6\xbe\x44\xd4\xb3\x59\xeb\xa6\xa8\x17\x80\xf0\xc4\xfc\xe5\xa0\x72\x0b\xf6\x27\x31\x2c\x1e\xd8\x52\xbf\x5a\x00\x85\xc7\xaa\x85\x2f\x89\x77\x84\x8d\x4b\x31\x81\x57\xd5\xbc\x43\x74\xcd\xd5\x4c\xa2\x79\xa0\xfb\x38\xc3\xa4\x94\x1d\xd5\x27\x2b\x04\xc1\x1e\xfc\x03\x70\xba\x8c\xe4\xb0\xba\xab\x81\x80\x0d\xed\x77\xd1\x6f\xf3\x41\x60\x0b\xc8\x2b\x4b\x3c\x4a\x8b\xa5\x08\x7a\x05\xec\x58\x12\xa7\x83\x87\x57\x4a\xd2\x19\x0a\xfc\xd1\xc9\xb4\x33\x3f\xca\x9b\x6a\x3b\xad\xcc\x1c\x6c\x80\x4e\xe4\x9b\x56\xd0\xd1\xb4\xff\xa7\xc0\xc7\x9a\x08\xbb\xe9\x41\xf0\xc0\xc9\x90\xdf\x56\x13\xae\x88\x4a\xad\x93\x58\x9b\xb5\x20\xb7\xb1\x43\x61\xa1\x98\xea\x10\x00\x65\xb9\x59\x4b\x80\x79\x32\x51\xba\xc6\xcd\x88\xcc\x2c\x22\x61\x7a\x83\x0d\xa1\x2c\xec\xf6\x13\xf3\xbe\x6c\x0d\xaa\xfa\xcc\xdd\xba\x03\x4b\x35\x74\x36\x25\xb2\x66\x41\x60\x38\xff\x68\xd8\xf8\xa4\x4e\x73\x9a\xc6\x13\xa4\xd4\x86\xe2\x96\xb0\x10\x46\x5f\x9b\x74\x11\xd9\xd4\x54\xee\x76\x61\x93\xc4\xad\xa6\xac\xcb\xe0\xef\xb3\x45\x80\x71\x36\x2f\x19\xeb\x69\xbb\x08\x39\xf4\x49\xe4\x2f\x4f\x7f\x0e\xb1\x52\x0c\x31\x78\x36\x0a\x51\x25\xc4\xcc\x95\x52\xcf\xc7\x66\x46\x08\xea\xb3\x6f\x1b\xec\x41\x47\xbd\x00\x69\x8f\x57\x37\x95\xcf\xee\x0d\x91\xa4\x9d\x91\xa5\x2a\xa6\xb8\x8c\xa6\x43\x39\xc8\x1f\xf2\xa4\x81\x08\x7b\x09\x56\x0e\x4b\x4b\x85\x81\xad\x8a\x22\x26\x41\x33\x7a\xb9\x32\xf6\x79\x83\xda\xf0\x53\x35\x0b\x1b\x3b\x2b\xc5\x73\x3d\xff\x33\xb3\xa5\x2c\x77\x43\x4a\x32\x54\xe1\x72\x68\x08\x28\xfe\x3b\xfb\x1b\x8d\xa4\x7d\xb7\x55\x2c\xba\xde\xff\x66\x2e\xde\x69\x2d\xa8\xb9\xc8\x43\xb0\x2d\x33\xc0\x4f\xcd\x63\xfc\x0a\x98\xdf\x29\x25\x07\x90\xdc\x1d\x83\x87\x6e\xd3\xdf\x98\xfa\x5b\xa0\xa6\x6d\x86\xac\x86\x91\x86\x32\x86\x4c\x49\x10\x1b\x06\x33\xa3\x06\xfc\x14\xd8\xda\x4f\x22\x72\xc0\x49\xfc\xda\xe1\xf4\xb1\xd8\x13\xff\xbb\x27\x09\x08\xee\xc0\x37\x9b\x2e\x31\x53\xac\x91\x63\x65\xb8\xfd\x8e\xc5\xe1\x7f\xb7\xc1\x71\x3e\x2d\x52\x24\x02\x80\xe0\x63\x0c\x12\x99\xd5\x4c\x98\x97\x83\xe8\x7d\xc6\xc7\x4c\x38\x5f\x38\x15\xe0\x79\xde\x5f\x2b\x12\x01\x58\xc0\x2e\x19\xd8\x9a\x14\xff\x91\x7c\x84\x15\x5d\x67\xa7\x14\x91\x61\xfc\xe3\x7d\x3b\x56\xe5\x97\x49\xcf\xc9\x35\x2b\x0e\x91\x2b\xea\xba\xc1\x7e\x68\xef\x1c\xfe\xce\x99\xb1\xeb\xf7\xc9\xe3\x17\x60\x24\x9a\x67\x45\x8f\x08\xc5\x9a\x5f\x88\x43\x49\x0a\xa9\xce\xe7\x94\x05\x97\x6d\x21\xec\x9a\x86\xe2\x67\xea\x0b\x59\x4e\x5e\x01\xc6\xef\x25\x27\xc7\x89\xe5\x58\x2c\xb2\xa7\x7c\xbc\xa6\xca\x60\xd9\xe3\xec\x21\xc8\x86\xd2\x21\x90\xf3\x3c\xeb\xb9\x7a\x8d\xe1\x92\x2b\x42\x01\x7f\x98\xe3\x8f\xb7\x87\x60\x8c\xcc\x17\x58\x96\x8e\xfd\x75\x21\xfb\x98\xde\xc2\xf0\xb3\xaf\x64\x36\x0a\xf6\x93\x30\x79\x7d\xbc\xad\xbd\x15\x76\x4b\xc9\xd7\x07\x58\xa3\x41\x34\xe6\x2a\xfd\x07\x22\x43\xa5\xa3\x3c\xf7\x49\x9a\xe6\xa7\x23\xde\x98\x9e\x52\x93\x70\xbc\xd0\x8e\x24\xe4\xdd\xc3\x56\x67\xb4\xe1\x1e\xb5\xfe\x97\xb4\x51\xcf\xa9\xb8\xc0\xeb\xd2\x31\x92\x83\x76\x70\x8a\xb1\x4d\x25\xa3\x39\x79\xb9\x40\xd9\x0e\x21\xb0\x38\x67\xa1\x0c\x6d\xad\x2a\x6b\x5b\x8c\xcb\x1e\x6b\xc8\x10\x55\x5b\xcf\x62\xea\xc8\xf6\x14\xb2\xe5\x01\x7f\x6d\x67\x93\xce\xb1\x45\xde\x0e\x69\xf1\xe7\x69\x37\x8d\xb9\xf5\xcd\x6f\x2b\x22\xcf\x5c\xc1\x19\xef\x04\x79\x55\xb1\xed\xab\xc8\x54\x7a\xdf\xa6\x8e\xf9\xbc\x74\x63\xc1\x35\x53\x4f\xa5\xf7\xa7\x0e\x55\x69\x7e\x63\xe0\xfc\x5a\x3c\xc3\x3b\xfc\x3d\xa5\x59\x04\x15\x3a\x1d\xc1\xc5\x84\xe4\xbb\xca\xab\xba\x73\x3c\xd9\xa1\xc6\x4c\x17\xc4\x75\xf7\x21\x0e\x12\x01\xb1\xb0\x6f\x46\xcd\xf1\xf8\x9c\x0c\xdc\x0b\x04\xd3\xe0\x58\x77\x4b\xe9\xa5\xac\x48\x06\x7a\x27\x3d\xe1\xaa\xf8\x36\x97\x55\xda\x18\x7a\xd0\xe5\x42\xf0\x2d\xfd\x05\xe3\xdd\x52\x4d\xe6\xa7\x33\x68\x1f\x96\xea\x09\x71\x64\x7c\x78\x2c\x5a\x6d\xb7\x79\x5b\x0f\xf8\xe3\x48\x44\x8a\x47\x35\xd4\x8a\x55\x9f\x00\x5f\xe4\xb5\x31\x59\x6a\x04\x97\x88\x5d\x93\xb8\x41\x00\xaa\x3a\x6c\x70\x5a\x9a\x92\x71\xad\xde\x50\xbd\x90\xb1\x16\x7d\x33\x0f\x4d\xab\x0f\xc2\xf3\x5e\xc3\x44\x5d\xc0\x4f\xa1\xc3\x82\x05\xaf\x05\x9b\xf8\x93\xb6\xba\xe4\x75\x0d\x82\x1e\x49\xf7\x5f\x13\x9e\xc3\xc1\x36\xce\xb3\xb9\x57\xf8\x62\x61\x65\xe0\xd2\x30\x63\x01\xf0\x09\xac\x12\xdc\xdf\x63\xda\x3e\xa8\xc8\x8c\x97\x0c\xb5\x82\x01\x9c\xe6\xaf\xe1\x06\x7b\x78\xfd\x30\x4f\x9a\xdd\x0b\xfa\x99\xa1\x65\x35\x3c\x6f\xfd\xde\xf7\x94\xe9\x53\x71\x58\xcd\x4a\xbe\xa7\xa8\xf4\x5d\x73\xea\xbf\x15\x58\x9c\xfa\xe3\x34\x4a\x40\xb8\xd2\x94\x7c\x04\x7e\x04\xa1\xa9\x18\xa1\xb0\x5a\x00\x15\x51\x25\xec\x23\xe3\xb7\x16\x7c\xe3\x5d\x99\x6b\x90\xfc\xfa\x1b\xf2\x84\xe4\x7d\x76\x56\x5c\xbf\x99\xe1\x94\x2d\xbc\x95\x13\x30\x48\x49\x4e\x49\x1a\x7a\x8d\x32\x4d\x46\x8a\x2f\x74\x0a\x12\x3b\xf6\x78\xc1\xc1\x38\x73\x45\xc0\xc5\xa2\x9f\x78\x0f\xa2\x4c\xb3\xaf\xc0\xa3\x21\xe0\x8f\x94\x15\x51\x54\x90\x8f\x06\xcf\x7c\x70\xf2\xf6\x7d\x9c\x62\x71\x8d\xc9\xcb\x7e\x25\xb2\x46\xdd\x5c\x4c\x06\xf3\x24\x88\x4d\x42\xad\x96\x30\x59\x92\xab\xdf\x69\x56\xac\xda\xb1\x33\xec\x3e\xcd\xc7\xf5\xf0\x89\x59\xdb\x82\x03\x1a\x33\xa9\x24\xb8\x82\x86\xe5\xc5\x8e\x4d\x26\x89\xb9\xae\x08\x1f\x9a\x7b\x7a\x38\x8b\x0a\x95\x94\x8f\x00\x1f\x20\x0e\xc0\xc8\x5c\xe6\xae\x25\xf5\x0c\xd9\x4e\x99\xf5\x93\x37\xc6\xea\x0d\x34\xd2\xa2\xb1\xf4\x13\x6d\x03\x1e\x42\x59\xe0\x2a\xca\x20\xf7\x11\x36\x1e\x24\xbd\x77\xee\x19\x45\x99\x36\x81\x7b\xf9\x34\xf2\x47\x4b\x61\x2e\x51\xc0\xd1\x3a\x84\x16\x98\xd9\xbb\x04\xcd\xd8\x2c\x1b\x03\xe7\xe4\x4a\x44\x80\xd0\x35\xae\xa4\xeb\x2e\x7b\x69\xc4\x4c\x1e\xe1\xdc\xf7\x5a\x19\x36\x99\x44\xc3\x1c\xb1\x37\x21\xb6\x8b\xf6\x80\x94\xa1\xa9\xb3\xf7\xa1\x1b\xb3\xcf\x64\x1b\x1d\x1e\x17\x8d\x82\xb9\xcc\x47\x25\x23\x69\xf2\x0d\x7e\x46\x79\x61\x7c\x50\xdb\x4e\x0d\x3d\x50\x9c\x64\xa6\x7f\x27\x4a\x92\x93\xe7\x62\xfc\x8c\x2d\xc8\x5a\x2c\x92\x22\x2d\x37\xda\x0c\x31\x10\x29\x97\xce\x2a\x75\x21\x9f\x5b\xc2\x65\x81\x71\x36\x84\x8d\xe7\x4b\xcb\xb2\xad\xc3\xc5\x3e\x5e\xfc\x6c\x25\x5c\x3a\xa2\x7b\x42\xcf\x04\x9c\xf7\x33\x59\xe3\x95\xe4\x31\x05\xbd\x02\x82\x62\x77\xb8\xde\x75\x87\x5f\x04\xcd\x36\x3f\x0e\xf8\xab\x07\x56\x9f\x83\x3e\x6d\xe7\x63\xd1\x21\x0b\x65\x80\x00\x0e\x40\xbc\xd5\xab\x5b\xe7\x9b\x1c\x6c\xf1\xad\x95\xfa\x2f\x36\xbe\x46\x50\x4e\xf8\x96\xd6\x90\xcc\xea\xc2\xcd\xcf\xa8\xad\xa0\x63\x40\xa3\x13\x08\x80\x46\x22\x9a\x8c\x6e\xcf\x6c\xd3\x43\x35\x79\xa3\x4f\xb7\x5d\x14\xa7\x5c\xc0\xe0\x1a\x25\x7d\xa1\x97\x53\xb6\x8a\x8a\xd9\x0a\x9a\xb7\x76\x84\x99\xbf\x17\xce\x56\xce\x0d\xf5\x67\xd3\xc1\x57\x26\x9c\x04\x12\xbd\xd5\x63\x35\x61\x58\x06\x8b\x28\x9a\x9a\xb3\xcc\xc1\x42\xb3\x74\x5c\x0d\xb2\x6b\x68\xa4\x6b\x99\xf1\x72\x87\x79\x9e\xa2\xab\x95\x48\x7f\xbc\x9c\xc5\x36\x86\xd7\xe3\x92\xe8\xee\x64\xa6\x67\xcd\x06\xbc\x12\x95\x2a\xb7\x04\x91\x90\x07\x4e\x55\xd0\x28\x54\xfb\xe1\xc7\xa9\xbb\xd9\x50\x8b\x6e\x0e\x82\x85\x00\xad\x21\x7d\x7b\x44\x30\x4f\x41\xa2\xdb\x0d\x40\xbc\xe3\xf8\x1d\x53\xaf\x1e\x74\xf3\x89\x30\x11\xed\x74\x53\x5c\x2d\x7e\x89\xc1\xeb\x29\x56\xd7\x9a\xea\x99\x2c\x4a\x52\xf7\x32\x34\x0c\x08\x97\xc5\x8f\xba\x40\xff\xf7\x50\xeb\x5f\x93\x8e\xd9\x3a\xc5\xae\xf4\x40\x58\xfa\xba\xbe\xd7\xff\x6b\x71\xce\x1e\xa5\x40\xd1\xb3\x0c\xe0\xeb\x2c\x8f\x4c\x61\x41\xc0\x0e\x2e\x33\xf4\xa9\xa8\x40\x9d\x71\x02\x72\xd5\x47\x04\x24\xab\xa9\x04\xb1\xb7\xd5\x5d\x01\xe2\xb0\xe5\xf3\x32\xf1\x22\x0c\xc9\xa3\x0c\x50\x34\xab\x6d\xab\x2c\x78\xd1\x07\x17\xac\xad\x4d\xf4\x56\xad\x61\xab\x87\xfa\xbf\x27\x6d\xea\xc0\xec\x90\x70\x19\xa0\xc5\x32\x7d\x1c\xf5\x78\x50\x78\xc5\x69\x01\xe8\x4a\x17\x2a\x67\xde\xb4\x32\x5d\xae\x20\xa8\x50\x93\xd3\x7b\xc0\x5a\x62\x28\xed\x98\x1a\x92\x29\x8f\xd8\xf9\xd8\x50\x4c\x97\x17\xee\xbe\x0d\x9d\x60\x42\xa5\xeb\x47\x38\x2e\x10\x1d\x63\x3a\xe2\x65\x1d\x03\xf9\x1f\x75\x88\x45\x3d\xc9\x11\x98\xd7\x8c\xfc\xa8\xba\xeb\x60\xdb\xd9\xf2\x5a\xe7\xde\xae\x0d\xbe\xfb\x02\x5e\xbb\xf3\x1a\xba\x0a\x65\x74\xe3\xb5\xe9\x26\x43\x81\x60\x9d\x7b\x91\x16\x1a\x28\x7f\x4c\xb8\xa1\x5b\x8a\x1b\x54\x6a\x28\xc8\x22\x8c\x8f\x41\xd4\x11\xc5\xa8\x45\x33', 2)

# cleanup
del pyarmor_runtime

